package FileMech;

$UNRAR = "unrar x -inul"; # command to use to open cbr files
$UNZIP = "unzip -qqj";    # command to use to open cbz files

=pod
=head1 MODULE

FileMech.pm - File Mechanics for 6reader

This module handles the file mechanics for 6reader
=cut

sub openFile {
  my $types = [
	       ['Comic Book Archives', ['.cbr', '.cbz']],
#	       ['All Files', '*',]
              ];
  printf STDERR qq(Inside openFile\n) if ($::DEBUG);
  $::comicFile = $::mw->getOpenFile(-defaultextension => '.cbr',
                               -filetypes => $types );

  print STDERR qq(User selected, "$::comicFile"\n) if ($::DEBUG);

  closeFile() if($::TMPFILE);
  FileMech::readFile();
  Page::firstPage();
} # openFile

sub readFile {
  $::TMPDIR = "/tmp/6reader." . time();
  $::TMPFILE = "${::TMPDIR}/6readerTmp.cb";

  print STDERR qq(Creating tmpdir, "$::TMPDIR"\n) if ($::DEBUG);

  unless(mkdir($::TMPDIR)) {
    rmdir($::TMPDIR);
    print STDERR qq(Unable to create tempdir, "$::TMPDIR"\n);
    Exit::cleanExit(-20);
  } # unless

  print STDERR qq(Extracting "$::comicFile" to "$::TMPDIR"\n) if ($::DEBUG);
  if ($::comicFile =~ /.cbr$/io) {
    $result = system(qq($UNRAR '$::comicFile' $::TMPDIR));
  } # if
  elsif ($::comicFile =~ /.cbz$/io) {
    $result = system(qq($UNZIP '$::comicFile' -d $::TMPDIR));
  } # if
  else {
    print STDERR "Error, can not open $::comicFile.  Can only open .cbr and .cbz files.\n";
    Exit::cleanExit(-15);
  } # else

  if($result) {
    print STDERR qq(Unable to extract "$::comicFile" to "$::TMPDIR"\n);
    Exit::cleanExit(-30);
  } # if
  print STDERR qq(Extraction complete.\n);
#
# at this point we should have the book opened as a set of files
# in $::TMPDIR
#
opendir(DIRHANDLE, $::TMPDIR);
my @pageFiles = sort grep(!/^\./, readdir(DIRHANDLE));
closedir(DIR);
unless(@pageFiles) {
  print STDERR qq(Unable to acquire any pages\n);
  cleanExit(-40);
} # unless
  my ($f, $n);
  foreach $f (@pageFiles) {
    print STDERR qq(renaming "$f" to ), sprintf("page%04d", $n), "\n";
    rename ("${::TMPDIR}/$f", $::TMPDIR . "/" . sprintf("page%04d", $n++));
  } #foreach
  $::PAGES = $#pageFiles;
print STDERR "Loaded ", $#pageFiles + 1, " pages\n" if ($::DEBUG);
#
# at this point we have the names of the files containing the 
# the pages in a nice sorted array called @pageFiles
#
# cbr files are set up so that sorted order by filename 
# inherently puts the pages in the correct book order
#
} #readFile

sub closeFile {
  printf STDERR qq(Inside closeFile\n) if ($::DEBUG);
  $::image->delete if($::image);
  $::SCALE = $DEFSCALE;
  Exit::cleanDir();
} # closeFile
;1
