package Page;

=pod
=head1 MODULE

Page.pm - Page mechanics for 6reader

This module contains methods that implement page mechanics for 6reader

=cut

sub showPage {
  printf STDERR qq(Inside showPage\n) if ($::DEBUG);
  printf STDERR qq(Scale = $::SCALE\n) if ($::DEBUG);
  if ($::SCALE == 1) {
    $::image->copy($::cacheImage);
  } # if
  else {
    $::image->delete if($::image);
    $::image = $::mw->Photo;
    $::image->blank;
    if ($::SCALE > 1) {
      printf STDERR qq(subsampling\n) if ($::DEBUG);
      $::image->copy($::cacheImage, -subsample => $::SCALE -shrink);
    } # if
    else {
      printf STDERR qq(zooming\n) if ($::DEBUG);
      $::image->copy($::cacheImage, -zoom => (-1 * $::SCALE));
    } # else
  } # else
  $::canvas->createImage(0, 0, -image=> $::image);
  $::canvas->configure(-scrollregion => [ $::canvas->bbox("all")]);

  Page::moveScreen();
} # showPage

sub setPage {
  printf STDERR qq(Inside setPage\n) if ($::DEBUG);
  printf STDERR qq(Caching page number $::PAGENUMBER\n) if ($::DEBUG);
  $::cacheImage = $::mw->Photo(-format => 'jpeg',
			       -file =>"$::TMPDIR/" . 
			       sprintf("page%04d", $::PAGENUMBER));
} # setPage

sub firstPage {
  printf STDERR qq(Inside firstPage\n) if ($::DEBUG);
  $::PAGENUMBER = 0;
  Page::setPage();
  Page::showPage();
} # firstPage

sub lastPage {
  printf STDERR qq(Inside lastPage\n) if ($::DEBUG);
  $::PAGENUMBER = $::PAGES;
  Page::setPage();
  Page::showPage();
} # firstPage

sub nextPage {
  printf STDERR qq(Inside nextPage\n) if ($::DEBUG);
  $::PAGENUMBER++;
  Page::setPage();
  Page::showPage();
} # firstPage

sub prevPage {
  printf STDERR qq(Inside prevPage\n) if ($::DEBUG);
  $::PAGENUMBER--;
  Page::setPage();
  Page::showPage();
} # firstPage

sub zoomIn {
  printf STDERR qq(Inside zoomIn\n) if ($::DEBUG);
  $::SCALE--;
  $::SCALE-- if ($::SCALE == 0);
  printf STDERR qq(New scale is $::SCALE\n) if ($::DEBUG);
  Page::showPage();
} #zoomIn

sub zoomOut {
  printf STDERR qq(Inside zoomOut\n) if ($::DEBUG);
  $::SCALE++;
  $::SCALE++ if ($::SCALE == 0);
  printf STDERR qq(New scale is $::SCALE\n) if ($::DEBUG);
  Page::showPage();
} #zoomIn

sub moveLeft {
  printf STDERR qq(Inside moveLeft\n) if ($::DEBUG);
  if ($::X) {
    $::X--;
    Page::moveScreen();
  } # if
} # moveLeft

sub moveRight {
  printf STDERR qq(Inside moveRight\n) if ($::DEBUG);
  if ($::X < $::image->width) {
    $::X++;
    Page::moveScreen();
  } # if
} # moveLeft

sub moveUp {
  printf STDERR qq(Inside moveUp\n) if ($::DEBUG);
  if ($::Y) {
    $::Y--;
    Page::moveScreen();
  } # if
} # moveLeft

sub moveDown {
  printf STDERR qq(Inside moveDown\n) if ($::DEBUG);
  if ($::Y < $::image->height) {
    $::Y++;
    Page::moveScreen();
  } # if
} # moveLeft

sub moveScreen {
  printf STDERR qq(Inside moveScreen\n) if ($::DEBUG);
  printf STDERR qq(Adjusting to X=$::X and Y=$::Y\n) if ($::DEBUG);
  $::canvas->xviewMoveto($::X);
  $::canvas->yviewMoveto($::Y);
} # moveScreen
;1
